@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Address Book Grouping and Pagination Plugin
-  * Copyright (c) 2008 Paul Lesniewski <paul@squirrelmail.org>,
+  * Copyright (c) 2008 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -11,7 +11,8 @@
   */
 
 global $agp_abook_pagination, $agp_abook_pagination_allow_override,
-       $agp_grouping, $max_pagination_links_to_show, $small_paginator_text;
+       $agp_grouping, $max_pagination_links_to_show,
+       $agp_enable_show_all, $small_paginator_text;
 
 
 // This controls if address grouping functionality
@@ -34,6 +35,16 @@ $agp_abook_pagination = 15;
 
 
 
+// This serves as the default value for whether or
+// not the "Show All" and "Paginate" links will be
+// made available
+//
+// This is only used in SquirrelMail 1.4.x
+//
+$agp_enable_show_all = 1;
+
+
+
 // Should users be able to control address
 // book pagination themselves?
 //
