@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Address Book Grouping and Pagination Plugin
-  * Copyright (c) 2008-2009 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2008 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -45,7 +45,7 @@ function abook_group_pagination_init()
 
    if (!@include_once (SM_PATH . 'config/config_abook_group_pagination.php'))
       if (!@include_once (SM_PATH . 'plugins/abook_group_pagination/config.php'))
-         if (!@include_once (SM_PATH . 'plugins/abook_group_pagination/config_default.php'))
+         if (!@include_once (SM_PATH . 'plugins/abook_group_pagination/config.sample.php'))
             return FALSE;
 
    return TRUE;
@@ -54,7 +54,7 @@ function abook_group_pagination_init()
    return load_config('abook_group_pagination',
                       array('../../config/config_abook_group_pagination.php',
                             'config.php',
-                            'config_default.php'),
+                            'config.sample.php'),
                       TRUE, TRUE);
 ----------- */
 
@@ -157,7 +157,7 @@ function abook_group_pagination_display_options_do()
       //
       else
       {  
-         $optpage_data['grps']['address_book'] = _("Address Book");
+         $optpage_data['grps']['abook_group_pagination'] = _("Address Book");
          if (empty($optpage_data['vals']['address_book']))
             $optpage_data['vals']['address_book'] = array();
          $optpage_data['vals']['address_book'] = array_merge($optpage_data['vals']['address_book'], $my_optpage_values);
